<?php
namespace Teknisa\CUS\Modules\Operacional\Controllers;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class Cus00400 extends \Zeedhi\Framework\Controller\Report  { 

    protected $dataSourceManager;
    protected $connection;
    protected $birtStrategy;

    public function __construct($crudService, $parameterBag, $dataSourceManager, $connection, $reportService, $birtStrategy, $util) {
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->dataSourceManager = $dataSourceManager;
        $this->connection = $connection;
        $this->reportService = $reportService;
        $this->birtStrategy = $birtStrategy;
        $this->util = $util;
    }

    protected $reportMapping = array(
        'CUS00400' => array(
            'strategy' => 'BIRT',
            'parameterMapping' => array(
                'CDFILIAL'     => 'P_CDFILIAL',
                'CDPRODUTOINI' => 'P_CDPRODINIC',
                'CDPRODUTOFIN' => 'P_CDPRODFINA',
                'CDPICTPROD'   => 'P_CDPICTPROD',
                'NRORG'        => 'P_NRORG'
            )
        )
    );

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
    }
    
    //Salva ou edita os dados enviados pelo front.
    public function save(DTO\Request $request, DTO\Response $response){
        $row = $request->getDataSet()->getRows();
        $sql = "";
        $query = "SELECT * FROM RATENESTO RNE WHERE RNE.CDPRODUTO = :CDPRODUTO AND ( RNE.CDFILIAL = :CDFILIAL ) AND ( RNE.CDSERVFILI = :CDSERVFILI )";
        
        try{
            $this->connection->beginTransaction();
            
            foreach($row as $key){
                $params = array(
                    "CDFILIAL" => $key['CDFILIAL'],
                    "CDPRODUTO" => $key['CDPRODUTO'],
                    "CDSERVFILI" => $key['CDSERVFILI'],
                    "PERATENESTO" => $key['PERATENESTO']
                );
                
                $validData = $this->connection->fetchAll($query, $params);
                // Verifica se possui dados ou não no banco de dados. Se tiver altera se não inseri
                if(empty($validData)){
                    $sql = "INSERT INTO RATENESTO (CDFILIAL, CDPRODUTO, CDSERVFILI, PERATENESTO) VALUES (:CDFILIAL, :CDPRODUTO, :CDSERVFILI, :PERATENESTO)";
                }else{
                    $sql = "UPDATE RATENESTO RNE SET PERATENESTO = :PERATENESTO WHERE RNE.CDPRODUTO = :CDPRODUTO AND (RNE.CDFILIAL   = :CDFILIAL)  AND (RNE.CDSERVFILI = :CDSERVFILI)";
                }
                
                if(floatval($key['PERATENESTO']) <= 0){
                   $sql = "DELETE FROM RATENESTO RNE WHERE RNE.CDPRODUTO = :CDPRODUTO AND (RNE.CDFILIAL   = :CDFILIAL)  AND (RNE.CDSERVFILI = :CDSERVFILI)";   
                   $params = array(
                        "CDFILIAL" => $key['CDFILIAL'],
                        "CDPRODUTO" => $key['CDPRODUTO'],
                        "CDSERVFILI" => $key['CDSERVFILI']
                    );
                }
                
                $this->connection->prepare($sql)->execute($params);
            }
            
            $result = $this->connection->commit();
        }catch (\Exception $e) {
            $this->connection->rollback();
            $response->setError(new DTO\Response\Error($e->getMessage(), 500));
        }
        
        $response->addDataSet(new DataSet("save", array($result)));
    }
    
    public function delete(DTO\Request $request, DTO\Response $response){
        $row = $request->getDataSet()->getRows();
        try{
            $this->connection->beginTransaction();
            
            foreach($row as $key){
                $params = array(
                    "CDFILIAL" => $key['CDFILIAL'],
                    "CDPRODUTO" => $key['CDPRODUTO']
                );
                $query = "DELETE RATENESTO WHERE (CDFILIAL = :CDFILIAL) AND (CDPRODUTO = :CDPRODUTO)";
                $this->connection->prepare($query)->execute($params);    
            }
            
            $result = $this->connection->commit();
            
            $response->addDataSet(new DataSet("delete", array($result)));
        }catch (\Exception $e) {
            $this->connection->rollback();
            $response->setError(new DTO\Response\Error($e->getMessage(), 500));
        }
    }
}