<?php
namespace Teknisa\CUS\Modules\Relatorio\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Cus00109 extends \Zeedhi\Framework\Controller\Report {
    protected $novoCodigo;
    protected $procedureConsumoPlanejado;
    protected $consplan;
    protected $servicoPorGrupo;
    protected $nrorg;
    protected $cdfilial;
    protected $nrConsPlan;
    protected $birtStrategy;
    protected $environment;
    protected $connection;
    
    public function __construct(ReportService $reportService, $novoCodigo, StoredProcedure $procedureConsplanGeral, $consplan, $servicoPorGrupo, $birtStrategy, $util, $environment, $connection) {
        $this->novoCodigo                = $novoCodigo;
        $this->procedureConsplanGeral    = $procedureConsplanGeral;
        $this->consplan                  = $consplan;
        $this->servicoPorGrupo           = $servicoPorGrupo;
        $this->birtStrategy              = $birtStrategy;
        $this->reportService             = $reportService;
        $this->util                      = $util;
        $this->environment               = $environment;
        $this->connection                = $connection;
    }
    
    protected $reportMapping = array (
        'CUS00109' => 
            array (
                'strategy' => 'BIRT',
                'parameterMapping' => 
                array (
                    'RADIO_DATA'    => 'P_TPDTCUS',
                    'DTINICIAL'     => 'P_DTINICIAL',
                    'DTFINAL'       => 'P_DTFINAL',
                    'CDTIPOCUSTO'   => 'P_NRTIPOCUSTO',
                    'NMTIPOCUSTO'   => 'P_NMCUSTO',
                    'NRCONSPLAN'    => 'P_NRCONSPLAN',
                    'LISTATIPOPRAT' => 'P_CDTIPOPRAT',
                    'TCDTIPOPRAT'   => 'P_TCDTIPOPRAT',
                    'CDPICTPRAT'    => 'P_CDPICTPRAT',
                    'CDPICTPROD'    => 'P_CDPICTPROD',
                    'P_NRORG'       => 'P_NRORG'
                ),
            ),
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        $row['NRLISTASERV'] = $this->util->insertLista($row['LISTASERVFILI']);
        $row['P_NRORG'] = $this->environment->getNrorgTrab();
    
        $procedure = new StoredProcedure($this->connection, 'CONSPLAN_GERAL');
        $procedure->addParam(new Param('P_NRLISTA',      Param::PARAM_INPUT,  $row['NRLISTASERV'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL',    Param::PARAM_INPUT,  $row['DTINICIAL'],   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL',      Param::PARAM_INPUT,  $row['DTFINAL'],     Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDPRODUTOS',   Param::PARAM_INPUT,  "CFP",               Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDSEPPRATO',   Param::PARAM_INPUT,  "P",                 Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PEACRESCIMO',  Param::PARAM_INPUT,  0,                   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_IDARREDOND',   Param::PARAM_INPUT,  "N",                 Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODUTOINI', Param::PARAM_INPUT,  " ",                 Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODUTOFIN', Param::PARAM_INPUT,  "zzzzzzzzzz",        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR',   Param::PARAM_INPUT,  $this->environment->getCdOperador(),  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRCONSPLANTH', Param::PARAM_INPUT,  'GERANOVCOD',        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRCONSPLAN',   Param::PARAM_OUTPUT, null,                Param::PARAM_TYPE_STR, 10));
        
        $procedureResult = $procedure->execute();
        $row['NRCONSPLAN'] = $procedureResult["P_NRCONSPLAN"];
    }
}